Michael Schwern wrote:

!Anyhow, the all target was removed from
!ExtUtils::MM_Unix->installbin() but left in
!ExtUtils::MM_VMS->installbin().  Probably just because someone forgot.
!
!Try this.  It also includes the suggestion about makemakerdflt.

OK.  These latter two patches help.  The C<@ Continue> action lines that
look like C<$(NOECHO) $(NOOP)> are still producing spurious newlines,
but I can live with it.  Here, for what it is worth is the patch against
your MM 5.52_01 dist:

diff -ru ExtUtils-MakeMaker-5.52_01_orig/lib/ExtUtils/MM_VMS.pm 
ExtUtils-MakeMaker-5.52_01/lib/ExtUtils/MM_VMS.pm
--- ExtUtils-MakeMaker-5.52_01_orig/lib/ExtUtils/MM_VMS.pm  Mon Mar 25 02:27:28 2002
+++ ExtUtils-MakeMaker-5.52_01/lib/ExtUtils/MM_VMS.pm Tue Mar 26 15:16:52 2002
@@ -507,7 +507,6 @@
     }

 push @m,"
-makemakerdflt : all

 .SUFFIXES :
 .SUFFIXES : \$(OBJ_EXT) .c .cpp .cxx .xs
@@ -1348,8 +1347,6 @@
     push @m, "
 EXE_FILES = @exefiles

-all :: @to
-     \$(NOECHO) \$(NOOP)

 realclean ::
 ";
End of Patch.

I'd like to see if we can eliminate the call to @make_ext all in the
vms/descrip_mms.template file, but I guess I'll have to wait for
a perl to incorporate MM 5.52_01 since the merge
would make my head ache.

I've not yet had time to address the test suite for MM...

Peter Prymmer


Reply via email to
diff -ru ExtUtils-MakeMaker-5.52_01_orig/lib/ExtUtils/MM_Unix.pm 
ExtUtils-MakeMaker-5.52_01/lib/ExtUtils/MM_Unix.pm
--- ExtUtils-MakeMaker-5.52_01_orig/lib/ExtUtils/MM_Unix.pm Tue Mar 26 00:29:58 2002
+++ ExtUtils-MakeMaker-5.52_01/lib/ExtUtils/MM_Unix.pm      Tue Mar 26 15:16:36 2002
@@ -704,8 +704,9 @@

     $attribs{DISTVNAME} ||= "$attribs{NAME}-$attribs{VERSION}";

     # We've already printed out a VERSION variable.
     delete $attribs{VERSION};
+    delete $attribs{NAME};

     my $make = '';
     while(my($var, $value) = each %attribs) {
@@ -704,8 +704,9 @@
     $attribs{DISTVNAME} ||= "$attribs{NAME}-$attribs{VERSION}";

-    # We've already printed out a VERSION variable.
+    # We've already printed out VERSION and NAME variables.
     delete $attribs{VERSION};